/*  GSMP - General Sound Manipulation Program
 *  Copyright (C) 2000-2001 Ren Rebe and Valentin Ziegler
 *
 *  SplashScreen.cc with some changes by Kristian Peters
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/* Short Description:
 *   The startup splash-screen.
 *   with some additions by Kristian Peters <kristian.peters@korseby.net>
 */

#include "plugins-gtk/SplashScreen.hh"
#include "config.hh"

SplashScreen::SplashScreen (Gtk::Main& i_kit)
  : m_kit(i_kit), Gtk::Window (GTK_WINDOW_DIALOG)
{
  /* set policy and title of the window */
  set_title ("GSMP - startup");
  set_policy (0,0,0);

  /* create new gtk-vbox */
  m_vbox = manage (new Gtk::VBox () );
  m_vbox -> set_border_width (0);
  m_vbox -> set_spacing (0);
  add (*m_vbox);

  /* load pixmap into buffer */
  string t_image = GSMP_PATH_DATA + string ("/pixmaps/splash.xpm");

  /* put pixmap into container */
  m_pixmap = manage (new Gtk::Pixmap (t_image) );
  m_vbox -> pack_start (*m_pixmap);

  /* draw version information */
  m_head_label = manage (new Gtk::Label ("GSMP " VERSION_STRING) );
  m_vbox -> pack_start (*m_head_label, true, true, 3);

  m_detail_label = manage (new Gtk::Label ("Welcome to GSMP") );
  m_vbox -> pack_start (*m_detail_label, true, true, 3);

  /* show ProgressBar */
  m_progressbar = manage (new Gtk::ProgressBar () );
  m_vbox -> pack_start (*m_progressbar);

  show_all ();
}

void SplashScreen::Update (string status_msg, double progress)
{
  m_detail_label -> set (status_msg);
  m_progressbar -> set_percentage (progress);
  show_all ();
  while (m_kit . events_pending ()) m_kit . iteration ();
}
